@@ -126,7 +126,7 @@ void QueryParserTest::testAccentSearch()
 {
     XapianQueryParser parser;
 
-    Xapian::Query query = parser.parseQuery(QString::fromLatin1("sng"));
+    Xapian::Query query = parser.parseQuery(QString::fromUtf8("sóng"));
     Xapian::Query q("song", 1, 1);
 
     QCOMPARE(query.serialise(), q.serialise());
